﻿using System;
using System.Collections.Generic;

namespace ElizaTest
{
    /// <summary>
    /// The Eliza tester.
    /// </summary>
    class Program
    {
        /// <summary>
        /// Defines the entry point of the application.
        /// </summary>
        /// <param name="args">The arguments.</param>
        static void Main(string[] args)
        {
            // Add the format free tests
            List<PatternTest> tests = new List<PatternTest>();
            tests.Add(new AlikePatternTest());
            tests.Add(new AlwaysPatternTest());
            tests.Add(new BecausePatternTest());
            tests.Add(new ComputerPatternTest());
            tests.Add(new DreamPatternTest());
            tests.Add(new ForeignPatternTest());
            tests.Add(new HelloPatternTest());
            tests.Add(new NamePatternTest());
            tests.Add(new NoPatternTest());
            tests.Add(new PerhapsPatternTest());
            tests.Add(new SorryPatternTest());
            tests.Add(new WhatPatternTest());
            tests.Add(new YesPatternTest());

            // Add the complex pattern tests
            tests.Add(new AmPatternTest());
            tests.Add(new ArePatternTest());
            tests.Add(new CanPatternTest());
            tests.Add(new DreamedPatternTest());
            tests.Add(new IfPatternTest());
            tests.Add(new IPatternTest());
            tests.Add(new RememberPatternTest());
            tests.Add(new WasPatternTest());
            tests.Add(new WerePatternTest());
            tests.Add(new WhyPatternTest());
            tests.Add(new YourPatternTest());

            // Run the tests
            PatternTest.ResetCounters();
            DateTime start = DateTime.Now;
            foreach(PatternTest test in tests) {
                test.Run();
            }
            TimeSpan elapsed = DateTime.Now - start;
            Console.WriteLine("\n{0} patterns, {1} rules and {2} responses tested in {3} sec",
                              PatternTest.PatternsTestedCount,
                              PatternTest.RulesTestedCount,
                              PatternTest.ResponsesTestedCount,
                              elapsed.TotalSeconds);

            // Close window
            Console.WriteLine("\nPress ENTER to close window...");
            Console.ReadLine();
        }
    }
}
